@@ -632,12 +632,17 @@ fr_process_set_err_line_func (FrProcess *process,
 static gboolean check_child (gpointer data);
 
 
-static void child_setup (gpointer user_data)
+static void
+child_setup (gpointer user_data)
 {
 	FrProcess *process = user_data;
 
 	if (process->priv->use_standard_locale)
 		putenv ("LC_MESSAGES=C");
+
+	/* detach from the tty */
+
+	setsid ();
 }
 
 
@@ -826,8 +831,10 @@ check_child (gpointer data)
 				process->error.status = WEXITSTATUS (status);
 			}
 		}
-		else
+		else {
 			process->error.type = FR_PROC_ERROR_EXITED_ABNORMALLY;
+			process->error.status = 255;
+		}
 	}
 
 	process->priv->command_pid = 0;
